==> vls-0.3.2.tar.bz2: vls-0.3.2/src/server/config.h <==
/*******************************************************************************
* config.h: Configuration variables
*-------------------------------------------------------------------------------
* (c)1999-2001 VideoLAN
* $Id: config.h.in,v 1.3 2001/11/27 16:37:51 bozo Exp $
*
* Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*-------------------------------------------------------------------------------
*
*******************************************************************************/


#ifndef _CONFIG_H_
#define _CONFIG_H_


//------------------------------------------------------------------------------
// Program description
//------------------------------------------------------------------------------
#define PGRM_VERSION    "0.3.2"
#define PGRM_INFO       "VideoLAN Server v 0.3.2 (" __DATE__ ") " \
                        "- (c)1999-2001 VideoLAN\n"

#define PLUGIN_PATH     "/usr/lib/videolan/vls"


#else
#error "Multiple inclusions of config.h"
#endif

==> vls-0.5.1.tar.bz2: vls-0.5.1/src/server/config.h <==
/*******************************************************************************
* config.h: Configuration variables
* Please do not forget to update config.h.win when modifying config.h.in !!
*  --Meuuh
*-------------------------------------------------------------------------------
* (c)1999-2001 VideoLAN
* $Id: config.h.in,v 1.4.4.1 2003/05/16 19:43:59 nitrox Exp $
*
* Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*-------------------------------------------------------------------------------
*
*******************************************************************************/


#ifndef _CONFIG_H_
#define _CONFIG_H_


//------------------------------------------------------------------------------
// Program description
//------------------------------------------------------------------------------
#define PGRM_VERSION    "0.5.0"
#define PGRM_INFO       "VideoLAN Server v 0.5.0 (" __DATE__ ") " \
                        "- (c)1999-2003 VideoLAN\n"

#define PLUGIN_PATH     "/usr/local/lib/videolan/vls"


#else
#error "Multiple inclusions of config.h"
#endif
